@@ -1,6 +1,6 @@
 /*
 
-  $Id: virtmodem.c,v 1.47 2006/08/06 20:42:20 pkot Exp $
+  $Id: virtmodem.c,v 1.50 2007/11/07 18:28:19 pkot Exp $
 
   G N O K I I
 
@@ -78,7 +78,6 @@
 #ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 #endif
-#include <unistd.h>
 #include <sys/socket.h>
 #include <sys/wait.h>
 #include <sys/uio.h>
@@ -140,7 +139,7 @@ bool gn_vm_initialise(const char *iname, const char *bindir, bool debug_mode, bo
 
 	if (GSMInit) {
 		dprintf("Initialising GSM\n");
-		if (!gn_cfg_phone_load(iname, sm)) return false;
+		if (gn_cfg_phone_load(iname, sm) != GN_ERR_NONE) return false;
 		if ((VM_GSMInitialise(sm) != GN_ERR_NONE)) {
 			fprintf (stderr, _("gn_vm_initialise - VM_GSMInitialise failed!\n"));
 			return (false);
@@ -354,10 +353,13 @@ static int VM_PtySetup(const char *bindir)
 	}
 
 	if (bindir) {
-		strncpy(mgnokiidev, bindir, 200);
-		strcat(mgnokiidev, "/");
+		strncpy(mgnokiidev, bindir, sizeof(mgnokiidev));
+		strncat(mgnokiidev, "/", sizeof(mgnokiidev) - strlen(mgnokiidev));
+	} else {
+		mgnokiidev[0] = 0;
 	}
-	strncat(mgnokiidev, "mgnokiidev", 200 - strlen(bindir));
+
+	strncat(mgnokiidev, "mgnokiidev", sizeof(mgnokiidev) - strlen(mgnokiidev));
 
 	if (access(mgnokiidev, X_OK) != 0) {
 		fprintf(stderr, _("Cannot access %s, check the bindir in your gnokiirc!\n"), mgnokiidev);
