@@ -1,6 +1,6 @@
 /*
 
-  $Id: unixserial.c,v 1.45 2007/09/04 17:18:39 dforsi Exp $
+  $Id: unixserial.c,v 1.47 2008/01/09 13:09:47 ladis Exp $
 
   G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999-2000  Hugh Blemings & Pavel Jank ml.
+  Copyright (C) 1999-2000  Hugh Blemings & Pavel Janik ml.
   Copyright (C) 2001       Chris Kemp, Manfred Jonsson, Jank Kratochvil
   Copyright (C) 2002       Ladis Michl, Pavel Machek
   Copyright (C) 2001-2004  Pawel Kot
@@ -30,13 +30,12 @@
   
 */
 
+#include "config.h"
+
 #include "misc.h"
 #include "gnokii.h"
 #include "gnokii-internal.h"
-
-/* Do not compile this file under Win32 systems. */
-
-#ifndef WIN32
+#include "devices/serial.h"
 
 #include <errno.h>
 #include <fcntl.h>
@@ -47,9 +46,7 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-
 #include <termios.h>
-#include "devices/unixserial.h"
 
 #ifdef HAVE_SYS_IOCTL_COMPAT_H
 #  include <sys/ioctl_compat.h>
@@ -497,5 +494,3 @@ gn_error serial_flush(int fd, struct gn_statemachine *state)
 
 	return GN_ERR_NONE;
 }
-
-#endif /* WIN32 */
