@@ -1,6 +1,6 @@
 /*
 
-  $Id: gsm-networks.c,v 1.51 2007/12/15 18:14:00 pkot Exp $
+  $Id: gsm-networks.c,v 1.54 2008/06/04 11:53:45 dforsi Exp $
 
   G N O K I I
 
@@ -48,7 +48,7 @@ static gn_country countries[] = {
 	{"213", "Andorra"},
 	{"631", "Angola"},
 	{"365", "Anguilla"},
-	{"344", "Antigua & Barbuda"},
+	{"344", "Antigua and Barbuda"},
 	{"722", "Argentina"},
 	{"283", "Armenia"},
 	{"363", "Aruba"},
@@ -57,11 +57,13 @@ static gn_country countries[] = {
 	{"400", "Azerbaijan"},
 	{"426", "Bahrain"},
 	{"880", "Bangladesh"},
+	{"338", "Barbados"},
 	{"342", "Barbados"},
 	{"257", "Belarus"},
 	{"206", "Belgium"},
 	{"702", "Belize"},
 	{"616", "Benin"},
+	{"350", "Bermuda"},
 	{"402", "Bhutan"},
 	{"218", "Bosnia and Herzegovina"},
 	{"652", "Botswana"},
@@ -101,7 +103,7 @@ static gn_country countries[] = {
 	{"542", "Fiji"},
 	{"244", "Finland"},
 	{"208", "France"},
-	{"547", "French Polynesia (France)"},
+	{"547", "French Polynesia"},
 	{"628", "Gabon"},
 	{"607", "Gambia"},
 	{"282", "Georgia"},
@@ -119,6 +121,7 @@ static gn_country countries[] = {
 	{"454", "Hong Kong"},
 	{"216", "Hungary"},
 	{"274", "Iceland"},
+	{"404", "India"},
 	{"405", "India"},
 	{"510", "Indonesia"},
 	{"901", "International"},
@@ -134,6 +137,7 @@ static gn_country countries[] = {
 	{"401", "Kazakhstan"},
 	{"639", "Kenya"},
 	{"450", "Korea"},
+	{"212", "Kosovo"},
 	{"419", "Kuwait"},
 	{"437", "Kyrgyzstan"},
 	{"457", "Laos"},
@@ -166,7 +170,7 @@ static gn_country countries[] = {
 	{"649", "Namibia"},
 	{"429", "Nepal"},
 	{"204", "Netherlands"},
-	{"362", "Netherlands Antilles (Netherlands)"},
+	{"362", "Netherlands Antilles"},
 	{"546", "New Caledonia"},
 	{"530", "New Zealand"},
 	{"710", "Nicaragua"},
@@ -191,7 +195,7 @@ static gn_country countries[] = {
 	{"635", "Rwanda"},
 	{"308", "Saint Pierre and Miquelon"},
 	{"549", "Samoa"},
-	{"222", "San Marino"},
+	{"292", "San Marino"},
 	{"626", "Sao Tome and Principe"},
 	{"420", "Saudi Arabia"},
 	{"608", "Senegal"},
@@ -214,7 +218,7 @@ static gn_country countries[] = {
 	{"436", "Tajikistan"},
 	{"640", "Tanzania"},
 	{"520", "Thailand"},
-	{"615", "Togolese Republic"},
+	{"615", "Togo"},
 	{"539", "Tonga"},
 	{"374", "Trinidad and Tobago"},
 	{"605", "Tunisia"},
@@ -224,13 +228,15 @@ static gn_country countries[] = {
 	{"255", "Ukraine"},
 	{"424", "United Arab Emirates"},
 	{"234", "United Kingdom"},
+	{"310", "United States of America"},
+	{"311", "United States of America"},
 	{"316", "United States of America"},
 	{"748", "Uruguay"},
 	{"434", "Uzbekistan"},
 	{"541", "Vanuatu"},
-	{"222", "Vatican"},
+	{"225", "Vatican"},
 	{"734", "Venezuela"},
-	{"452", "Vietnam"},
+	{"452", "Viet Nam"},
 	{"421", "Yemen"},
 	{"645", "Zambia"},
 	{"648", "Zimbabwe"},
@@ -1312,6 +1318,19 @@ GNOKII_API char *gn_network_code_find(char *network_name, char *country_name)
 	return networks[index].code ? networks[index].code : _("undefined");
 }
 
+GNOKII_API char *gn_country_name_translate(char *country_name)
+{
+	/*
+	 * Retrieve the translation of the given @country_name
+	 * if the iso-codes package is installed and NLS is enabled.
+	 *
+	 * Use this function only with gn_country_get() because
+	 * gn_country_name_get() and gn_network2country() alreadly
+	 * return translated names.
+	 */
+	return dgettext("iso_3166", country_name);
+}
+
 GNOKII_API char *gn_country_name_get(char *country_code)
 {
 	int index = 0;
@@ -1319,15 +1338,19 @@ GNOKII_API char *gn_country_name_get(char *country_code)
 	while (countries[index].code &&
 	       strncmp(countries[index].code, country_code, 3)) index++;
 
-	return countries[index].name ? countries[index].name : _("unknown");
+	return countries[index].name ? gn_country_name_translate(countries[index].name) : _("unknown");
 }
 
 GNOKII_API char *gn_country_code_get(char *country_name)
 {
+	/* 
+	 * If the iso-codes package is installed and NLS is enabled
+	 * @country_name must be given in the current language.
+	 */
 	int index = 0;
 
 	while (countries[index].name &&
-	       strcasecmp(countries[index].name, country_name)) index++;
+	       strcasecmp(gn_country_name_translate(countries[index].name), country_name)) index++;
 
 	return countries[index].code ? countries[index].code : _("undefined");
 }
