@@ -1,6 +1,6 @@
 /*
 
-  $Id: misc.c,v 1.136 2008/02/21 11:23:40 dforsi Exp $
+  $Id: misc.c,v 1.141 2008/09/10 21:03:08 pkot Exp $
 
   G N O K I I
 
@@ -134,7 +134,7 @@ static gn_phone_model models[] = {
 	{"3108",  "RH-6",	PM_OLD_DEFAULT },
 	{"3110",  "NHE-8",	PM_OLD_DEFAULT | PM_DATA },
 	{"3110",  "0310" ,	PM_OLD_DEFAULT | PM_DATA }, /* NHE-8 */
-	{"3110c", "RM-237",     PM_DEFAULT }, /* Nokia 3110 classic */
+	{"3110c", "RM-237",     PM_DEFAULT | PM_SMSFILE }, /* Nokia 3110 classic */
 	{"3120",  "RH-19",	PM_DEFAULT },
 	{"3120b", "RH-50",	PM_DEFAULT },
 	{"3200",  "RH-30",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
@@ -158,6 +158,7 @@ static gn_phone_model models[] = {
 	{"3390",  "NPB-1",	PM_OLD_DEFAULT },
 	{"3395",  "NPB-1B",	PM_OLD_DEFAULT },
 	{"3410",  "NHM-2",	PM_OLD_DEFAULT | PM_NETMONITOR },
+	{"3500c", "RM-272",	PM_DEFAULT },
 	{"3510",  "NHM-8",	PM_DEFAULT },
 	{"3510i", "RH-9",	PM_DEFAULT },
 	{"3520",  "RH-21",	PM_DEFAULT },
@@ -271,6 +272,7 @@ static gn_phone_model models[] = {
 	{"7260",  "RM-17",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7270",  "RM-8",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7280",  "RM-14",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
+	{"7373",  "RM-209",	PM_DEFAULT },
 	{"7600",  "NMM-3",	PM_DEFAULT | PM_XGNOKIIBREAKAGE },
 	{"7650",  "NHL-2NA",	PM_DEFAULT },
 	{"8110",  "0423" ,	PM_OLD_DEFAULT | PM_DATA }, /* NHE-6BX */
@@ -308,6 +310,7 @@ static gn_phone_model models[] = {
 	{"9210i", "RAE-5N",	PM_OLD_DEFAULT },
 	{"9290",  "RAE-3N",	PM_OLD_DEFAULT },
 	{"N70",   "RM-84",      PM_DEFAULT },
+	{"N73",   "RM-133",	PM_DEFAULT },
 	{"RPM-1", "RPM-1",	PM_OLD_DEFAULT | PM_DATA },
 	{"Card Phone 1.0", "RPE-1",	PM_OLD_DEFAULT | PM_DATA },
 	{"Card Phone 2.0", "RPM-1",	PM_OLD_DEFAULT | PM_DATA },
@@ -569,7 +572,12 @@ char **gnokii_strsplit(const char *string, const char *delimiter, int tokens)
 	if (!string || !delimiter || !tokens)
 		return NULL;
 
-	strings = calloc(tokens + 1, sizeof(char *));
+	/*
+	 * Last two elements are:
+	 *  - leftover from the input line
+	 *  - NULL (required by gnokii_strfreev())
+	 */
+	strings = calloc(tokens + 2, sizeof(char *));
 
 	while ((tmp = strstr(left, delimiter)) != NULL && (count < tokens)) {
 		str = malloc((tmp - left) + 1);
@@ -581,6 +589,11 @@ char **gnokii_strsplit(const char *string, const char *delimiter, int tokens)
 	}
 
 	strings[count] = strdup(left);
+	/*
+	 * Make NULL termination explicit even if it is done via calloc().
+	 * gnokii_strfreev() requires it to be NULL-terminated.
+	 */
+	strings[count + 1] = NULL;
 
 	for (count = 0; count < tokens; count++) {
 		dprintf("strings[%d] = %s\n", count, strings[count]);
