@@ -1,6 +1,6 @@
 /*
 
-  $Id: atsoer.c,v 1.22 2008/05/30 17:17:25 pkot Exp $
+  $Id: atsoer.c,v 1.28 2008/07/08 09:37:17 dforsi Exp $
 
   G N O K I I
 
@@ -61,6 +61,7 @@ static gn_error se_at_memory_type_set(gn_memory_type mt, struct gn_statemachine
 		/* BC is "Own Business Card" as per the Sony Ericsson documentation */
 		if (strcmp(memory_name, "ON") == 0)
 			memory_name = "BC";
+		at_set_charset(&data, state, AT_CHAR_GSM);
 		len = snprintf(req, sizeof(req), "AT+CPBS=\"%s\"\r", memory_name);
 		ret = sm_message_send(len, GN_OP_Init, req, state);
 		if (ret != GN_ERR_NONE)
@@ -101,23 +102,24 @@ static gn_error ReplyMemoryStatus(int messagetype, unsigned char *buffer, int le
 			(!strncmp(buf, "+CPBR:", 6) || !strncmp(buf + 1, "+CPBR:", 6)))
 			counter++;
 	}
-	data->memory_status->used = counter;
-	data->memory_status->free = drvinst->memorysize - counter;
+	data->memory_status->used += counter;
+	data->memory_status->free = drvinst->memorysize - data->memory_status->used;
 
-	dprintf("Got %d entries\n", counter);
 	return error;
 }
 
 /*
  * Calculate phonebook size for SonyEricsson phones: they don't respond
  * with memory stats to AT+CPBS. Calculate by reading and counting all
- * entries (which is fast -- just one command).
+ * entries (which is pretty fast).
  */
+#define PHONEBOOKREAD_CHUNK_SIZE 200
 static gn_error AT_GetMemoryStatus(gn_data *data, struct gn_statemachine *state)
 {
 	at_driver_instance *drvinst = AT_DRVINST(state);
 	gn_error ret = GN_ERR_NONE;
 	char req[32];
+	int top, bottom;
 
 	ret = se_at_memory_type_set(data->memory_status->memory_type,  state);
 	if (ret)
@@ -125,12 +127,29 @@ static gn_error AT_GetMemoryStatus(gn_data *data, struct gn_statemachine *state)
 	ret = state->driver.functions(GN_OP_AT_GetMemoryRange, data, state);
 	if (ret)
 		return ret;
-	memset(req, 0, 32);
-	snprintf(req, 31, "AT+CPBR=%d,%d\r", drvinst->memoryoffset + 1, drvinst->memorysize + drvinst->memoryoffset);
-	ret = sm_message_send(strlen(req), GN_OP_GetMemoryStatus, req, state);
-	if (ret)
-		return GN_ERR_NOTREADY;
-	return sm_block_no_retry(GN_OP_GetMemoryStatus, data, state);
+	data->memory_status->used = 0;
+	bottom = 0;
+	at_set_charset(data, state, AT_CHAR_UCS2);
+	top = (bottom + PHONEBOOKREAD_CHUNK_SIZE > drvinst->memorysize) ? drvinst->memorysize : bottom + PHONEBOOKREAD_CHUNK_SIZE;
+	while (top <= drvinst->memorysize) {
+		snprintf(req, sizeof(req) - 1, "AT+CPBR=%d,%d\r", drvinst->memoryoffset + 1 + bottom, top + drvinst->memoryoffset);
+		ret = sm_message_send(strlen(req), GN_OP_GetMemoryStatus, req, state);
+		if (ret)
+			return GN_ERR_NOTREADY;
+		ret = sm_block_no_retry(GN_OP_GetMemoryStatus, data, state);
+		if (ret)
+			return ret;
+
+		bottom = top;
+		top = bottom + PHONEBOOKREAD_CHUNK_SIZE;
+		if (bottom >= drvinst->memorysize)
+			break;
+		if (top > drvinst->memorysize)
+			top = drvinst->memorysize;
+	}
+	dprintf("Got %d entries\n", data->memory_status->used);
+
+	return ret;
 }
 
 void at_sonyericsson_init(char* foundmodel, char* setupmodel, struct gn_statemachine *state)
