@@ -1,6 +1,6 @@
 /*
 
-  $Id: generic.c,v 1.19 2007/12/04 19:27:35 hadess Exp $
+  $Id: generic.c,v 1.21 2008/05/30 19:10:06 pkot Exp $
 
   G N O K I I
 
@@ -27,7 +27,7 @@
   Copyright (C) 2001-2002 Pawel Kot
   Copyright (C) 2002      Ladis Michl
 
-  This file provides useful functions for all phones
+  This file provides useful functions for all phones.
   See README for more details on supported mobile phones.
 
   The various routines are called pgen_(whatever).
@@ -42,7 +42,7 @@
 /* If we do not support a message type, print out some debugging info */
 gn_error pgen_incoming_default(int messagetype, unsigned char *buffer, int length, struct gn_statemachine *state)
 {
-	dprintf("Unknown Message received [type (%02x) length (%d): \n", messagetype, length);
+	dprintf("Unknown Message received [type (%02x) length (%d)]: \n", messagetype, length);
 	sm_message_dump(gn_log_debug, messagetype, buffer, length);
 
 	return GN_ERR_NONE;
