@@ -1,6 +1,6 @@
 /*
 
-  $Id: vcal.c,v 1.20 2007/11/07 18:28:18 pkot Exp $
+  $Id: vcal.c,v 1.25 2008/06/24 09:16:53 hadess Exp $
 
   G N O K I I
 
@@ -40,7 +40,6 @@
  * Define it unconditionally to have nicer code below. */
 static const char gnokii_version[] = VERSION;
 
-
 #ifdef HAVE_LIBICAL
 /* needs gnokii-internal.h for string_base64() and utf8_encode() */
 #  include "gnokii-internal.h"
@@ -70,11 +69,48 @@ static inline const char *get_prodid()
 	return vcal_prodid;
 }
 
+typedef int (*print_func) (void *data, const char *fmt, ...);
+
+typedef struct {
+	char *str;
+	char *end;
+	unsigned int len;
+} ical_string;
+
+static void ical_append_printf(ical_string *str, const char *fmt, ...)
+{
+	char buf[1024];
+	va_list ap;
+	int len;
+
+	va_start(ap, fmt);
+	vsnprintf(buf, sizeof(buf), fmt, ap);
+	va_end(ap);
+
+	if (str->str == NULL) {
+		str->str = strdup (buf);
+		str->len = strlen (buf) + 1;
+		return;
+	}
+
+	len = strlen (buf);
+	str->str = realloc(str->str, len + str->len);
+
+	memcpy (str->str + str->len - 1, buf, len);
+	str->len = str->len + len;
+	str->end = str->str + str->len;
+
+	/* NULL-terminate the string now */
+	*(str->end - 1) = '\0';
+}
+
 /*
 	ICALENDAR Reading functions
  */
-GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
+GNOKII_API char * gn_calnote2icalstr (gn_calnote *calnote)
 {
+	ical_string str;
+
 #ifdef HAVE_LIBICAL
 #  define MAX_PROP_INDEX 5
 	icalcomponent *pIcal = NULL;
@@ -83,6 +119,8 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	int iprop = 0;
 	char compuid[64];
 
+	memset(&str, 0, sizeof (str));
+
 	/* In at least some Nokia phones it is possible to skip the year of
 	   birth, in this case year == 0xffff, so we set it to the arbitrary
 	   value of 1800 */
@@ -189,7 +227,7 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 
 			icalstr = icalstrbuf;
 		}
-		fprintf(f, "%s\n", icalstr);
+		ical_append_printf(&str, "%s\n", icalstr);
 		dprintf("%s\n", icalstr);
 		if (icalstrbuf)
 			free(icalstrbuf);
@@ -199,48 +237,50 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 	} else {
 		dprintf("ERROR in icalcomponent_vanew()\n");
 	}
-	return GN_ERR_NONE;
+	return str.str;
 #else
-	fprintf(f, "BEGIN:VCALENDAR\r\n");
-	fprintf(f, "VERSION:1.0\r\n");
-	fprintf(f, "BEGIN:VEVENT\r\n");
-	fprintf(f, "CATEGORIES:");
+	memset(&str, 0, sizeof (str));
+
+	ical_append_printf(&str, "BEGIN:VCALENDAR\r\n");
+	ical_append_printf(&str, "VERSION:1.0\r\n");
+	ical_append_printf(&str, "BEGIN:VEVENT\r\n");
+	ical_append_printf(&str, "CATEGORIES:");
 	switch (calnote->type) {
 	case GN_CALNOTE_MEMO:
-		fprintf(f, "MISCELLANEOUS\r\n");
+		ical_append_printf(&str, "MISCELLANEOUS\r\n");
 		break;
 	case GN_CALNOTE_REMINDER:
-		fprintf(f, "REMINDER\r\n");
+		ical_append_printf(&str, "REMINDER\r\n");
 		break;
 	case GN_CALNOTE_CALL: 
-		fprintf(f, "PHONE CALL\r\n");
-		fprintf(f, "SUMMARY:%s\r\n", calnote->phone_number);
-		fprintf(f, "DESCRIPTION:%s\r\n", calnote->text);
+		ical_append_printf(&str, "PHONE CALL\r\n");
+		ical_append_printf(&str, "SUMMARY:%s\r\n", calnote->phone_number);
+		ical_append_printf(&str, "DESCRIPTION:%s\r\n", calnote->text);
 		break; 
 	case GN_CALNOTE_MEETING: 
-		fprintf(f, "MEETING\r\n"); 
+		ical_append_printf(&str, "MEETING\r\n"); 
 		if (calnote->mlocation[0])
-			fprintf(f, "LOCATION:%s\r\n", calnote->mlocation);
+			ical_append_printf(&str, "LOCATION:%s\r\n", calnote->mlocation);
 		break; 
 	case GN_CALNOTE_BIRTHDAY: 
-		fprintf(f, "SPECIAL OCCASION\r\n"); 
+		ical_append_printf(&str, "SPECIAL OCCASION\r\n"); 
 		break; 
 	default: 
-		fprintf(f, "UNKNOWN\r\n"); 
+		ical_append_printf(&str, "UNKNOWN\r\n"); 
 		break; 
 	} 
 	if (calnote->type != GN_CALNOTE_CALL)
-		fprintf(f, "SUMMARY:%s\r\n", calnote->text);
-	fprintf(f, "DTSTART:%04d%02d%02dT%02d%02d%02d\r\n", calnote->time.year,
+		ical_append_printf(&str, "SUMMARY:%s\r\n", calnote->text);
+	ical_append_printf(&str, "DTSTART:%04d%02d%02dT%02d%02d%02d\r\n", calnote->time.year,
 		calnote->time.month, calnote->time.day, calnote->time.hour, 
 		calnote->time.minute, calnote->time.second); 
 	if (calnote->end_time.year) {
-		fprintf(f, "DTEND:%04d%02d%02dT%02d%02d%02d\r\n", calnote->end_time.year, 
+		ical_append_printf(&str, "DTEND:%04d%02d%02dT%02d%02d%02d\r\n", calnote->end_time.year, 
 			calnote->end_time.month, calnote->end_time.day, calnote->end_time.hour, 
 			calnote->end_time.minute, calnote->end_time.second); 
 	}
 	if (calnote->alarm.enabled) {
-		fprintf(f, "%sALARM:%04d%02d%02dT%02d%02d%02d\r\n",
+		ical_append_printf(&str, "%sALARM:%04d%02d%02dT%02d%02d%02d\r\n",
 		(calnote->alarm.tone ? "A" : "D"),
 		calnote->alarm.timestamp.year, 
 		calnote->alarm.timestamp.month, calnote->alarm.timestamp.day, calnote->alarm.timestamp.hour, 
@@ -251,41 +291,54 @@ GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
 		break; 
 	case GN_CALNOTE_DAILY: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=DAILY\r\n") :
-			fprintf(f, "RRULE:FREQ=DAILY;COUNT=%d\r\n", calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=DAILY\r\n") :
+			ical_append_printf(&str, "RRULE:FREQ=DAILY;COUNT=%d\r\n", calnote->occurrences);
 		break; 
 	case GN_CALNOTE_WEEKLY: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=WEEKLY\r\n") :
-			fprintf(f, "RRULE:FREQ=WEEKLY;COUNT=%d\r\n", calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=WEEKLY\r\n") :
+			ical_append_printf(&str, "RRULE:FREQ=WEEKLY;COUNT=%d\r\n", calnote->occurrences);
 		break; 
 	case GN_CALNOTE_2WEEKLY: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=WEEKLY;INTERVAL=2\r\n") :
-			fprintf(f, "RRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=%d\r\n", calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=WEEKLY;INTERVAL=2\r\n") :
+			ical_append_printf(&str, "RRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=%d\r\n", calnote->occurrences);
 		break; 
 	case GN_CALNOTE_MONTHLY: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=MONTHLY\r\n") :
-			fprintf(f, "RRULE:FREQ=MONTHLY;COUNT=%d\r\n", calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=MONTHLY\r\n") :
+			ical_append_printf(&str, "RRULE:FREQ=MONTHLY;COUNT=%d\r\n", calnote->occurrences);
 		break; 
 	case GN_CALNOTE_YEARLY: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=YEARLY\r\n") :
-			fprintf(f, "RRULE:FREQ=YEARLY;COUNT=%d\r\n", calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=YEARLY\r\n") :
+			ical_append_printf(&str, "RRULE:FREQ=YEARLY;COUNT=%d\r\n", calnote->occurrences);
 		break; 
 	default: 
 		calnote->occurrences ?
-			fprintf(f, "RRULE:FREQ=HOURLY;INTERVAL=%d\r\n", calnote->recurrence) :
-			fprintf(f, "RRULE:FREQ=HOURLY;INTERVAL=%d;COUNT=%d\r\n", calnote->recurrence, calnote->occurrences);
+			ical_append_printf(&str, "RRULE:FREQ=HOURLY;INTERVAL=%d\r\n", calnote->recurrence) :
+			ical_append_printf(&str, "RRULE:FREQ=HOURLY;INTERVAL=%d;COUNT=%d\r\n", calnote->recurrence, calnote->occurrences);
 		break; 
 	} 
-	fprintf(f, "END:VEVENT\r\n"); 
-	fprintf(f, "END:VCALENDAR\r\n");
-	return GN_ERR_NONE;
+	ical_append_printf(&str, "END:VEVENT\r\n"); 
+	ical_append_printf(&str, "END:VCALENDAR\r\n");
+	return str.str;
 #endif /* HAVE_LIBICAL */
 }
 
+GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote)
+{
+	char *vcal;
+	int retval;
+
+	vcal = gn_calnote2icalstr(calnote);
+	if (vcal == NULL)
+		return -1;
+	retval = fputs(vcal, f);
+	free (vcal);
+	return retval;
+}
+
 static inline gn_calnote_type str2calnote_type(const char *str)
 {
 	if (!str) {
@@ -302,27 +355,12 @@ static inline gn_calnote_type str2calnote_type(const char *str)
 	return GN_CALNOTE_REMINDER;
 }
 
-/* read a vcalendar event given by id from file f and store the data in calnote */
-GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
+#ifdef HAVE_LIBICAL
+static int gn_ical2calnote_real(icalcomponent *comp, gn_calnote *calnote, int id)
 {
 	int retval = GN_ERR_FAILED;
-#ifdef HAVE_LIBICAL
-	icalparser *parser = NULL;
-	icalcomponent *comp = NULL, *compresult = NULL;
 	struct icaltimetype dtstart = {0}, dtend = {0};
-
-	parser = icalparser_new();
-	if (!parser) {
-		return GN_ERR_FAILED;
-	}
-
-	icalparser_set_gen_data(parser, f);
-
-	comp = icalparser_parse(parser, ical_fgets);
-	if (!comp) {
-		icalparser_free(parser);
-		return GN_ERR_FAILED;
-	}
+	icalcomponent *compresult = NULL;
 
 	if (id < 1)
 		id = 1;
@@ -433,17 +471,88 @@ GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
 	}
 	if (compresult)
 		icalcomponent_free(compresult);
-	if (comp)
-		icalcomponent_free(comp);
-	if (parser)
-		icalparser_free(parser);
-#else
-	retval = GN_ERR_NOTIMPLEMENTED;
-#endif /* HAVE_LIBICAL */
+
 	return retval;
 }
+#endif /* HAVE_LIBICAL */
+
+/* read a vcalendar event given by id from file f and store the data in calnote */
+GNOKII_API gn_error gn_ical2calnote(FILE *f, gn_calnote *calnote, int id)
+{
+#ifdef HAVE_LIBICAL
+	icalparser *parser = NULL;
+	icalcomponent *comp = NULL;
+	gn_error retval;
+
+	parser = icalparser_new();
+	if (!parser) {
+		return GN_ERR_FAILED;
+	}
+
+	icalparser_set_gen_data(parser, f);
+
+	comp = icalparser_parse(parser, ical_fgets);
+	if (!comp) {
+		icalparser_free(parser);
+		return GN_ERR_FAILED;
+	}
+
+	retval = gn_ical2calnote_real(comp, calnote, id);
+
+	icalcomponent_free(comp);
+	icalparser_free(parser);
+
+	return retval;
+#else
+	return GN_ERR_NOTIMPLEMENTED;
+#endif /* HAVE_LIBICAL */
+}
+
+/* read a vcalendar event given by id from file f and store the data in calnote */
+GNOKII_API gn_error gn_icalstr2calnote(const char * ical, gn_calnote *calnote, int id)
+{
+#ifdef HAVE_LIBICAL
+	icalparser *parser = NULL;
+	icalcomponent *comp = NULL;
+	gn_error retval;
+
+	parser = icalparser_new();
+	if (!parser) {
+		return GN_ERR_FAILED;
+	}
+
+	comp = icalparser_parse_string (ical);
+	if (!comp) {
+		icalparser_free(parser);
+		return GN_ERR_FAILED;
+	}
+
+	retval = gn_ical2calnote_real(comp, calnote, id);
+
+	icalcomponent_free(comp);
+	icalparser_free(parser);
+
+	return retval;
+#else
+	return GN_ERR_NOTIMPLEMENTED;
+#endif /* HAVE_LIBICAL */
+}
 
 GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo)
+{
+	char *icalstr;
+
+	icalstr = gn_todo2icalstr(ctodo);
+	if (icalstr) {
+		fprintf(f, "%s\n", icalstr);
+		dprintf("%s\n", icalstr);
+		free(icalstr);
+	}
+
+	return GN_ERR_NONE;
+}
+
+GNOKII_API char * gn_todo2icalstr(gn_todo *ctodo)
 {
 #ifdef HAVE_LIBICAL
 	icalcomponent *pIcal = NULL;
@@ -469,48 +578,34 @@ GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo)
 			int icalstrlen = strlen(icalstr);
 			icalstrbuf = malloc(icalstrlen * 2 + 1);
 			utf8_encode(icalstrbuf, icalstrlen * 2, icalstr, icalstrlen);
-			icalstr = icalstrbuf;
+		} else {
+			icalstrbuf = strdup (icalstr);
 		}
-		fprintf(f, "%s\n", icalstr);
-		dprintf("%s\n", icalstr);
-		if (icalstrbuf)
-			free(icalstrbuf);
-
 		icalcomponent_free(pIcal);
-		pIcal = NULL;
+		return icalstrbuf;
 	}
-	return GN_ERR_NONE;
+	return NULL;
 #else
-	fprintf(f, "BEGIN:VCALENDAR\r\n");
-	fprintf(f, "VERSION:1.0\r\n"); 
-	fprintf(f, "BEGIN:VTODO\r\n"); 
-	fprintf(f, "PRIORITY:%i\r\n", ctodo->priority); 
-	fprintf(f, "SUMMARY:%s\r\n", ctodo->text); 
-	fprintf(f, "END:VTODO\r\n"); 
-	fprintf(f, "END:VCALENDAR\r\n");
-	return GN_ERR_NONE;
+	ical_string str;
+
+	memset(&str, 0, sizeof(str));
+	ical_append_printf(&str, "BEGIN:VCALENDAR\r\n");
+	ical_append_printf(&str, "VERSION:1.0\r\n"); 
+	ical_append_printf(&str, "BEGIN:VTODO\r\n"); 
+	ical_append_printf(&str, "PRIORITY:%i\r\n", ctodo->priority); 
+	ical_append_printf(&str, "SUMMARY:%s\r\n", ctodo->text); 
+	ical_append_printf(&str, "END:VTODO\r\n"); 
+	ical_append_printf(&str, "END:VCALENDAR\r\n");
+
+	return str.str;
 #endif /* HAVE_LIBICAL */
 }
 
-/* read the entry identified by id from the vcal file f and write it to the phone */
-GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
-{
 #ifdef HAVE_LIBICAL
-	icalparser *parser = NULL;
-	icalcomponent *comp = NULL, *compresult = NULL;
-
-	parser = icalparser_new();
-	if (!parser) {
-		return GN_ERR_FAILED;
-	}
-
-	icalparser_set_gen_data(parser, f);
-
-	comp = icalparser_parse(parser, ical_fgets);
-	if (!comp) {
-		icalparser_free(parser);
-		return GN_ERR_FAILED;
-	}
+/* read the entry identified by id from the vcal file f and write it to the phone */
+static int gn_ical2todo_real(icalcomponent *comp, gn_todo *ctodo, int id)
+{
+	icalcomponent *compresult = NULL;
 
 	if (id < 1)
 		id = 1;
@@ -534,10 +629,66 @@ GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
 		dprintf("Component found\n%s\n", icalcomponent_as_ical_string(compresult));
 	}
 	icalcomponent_free(compresult);
+
+	return GN_ERR_NONE;
+}
+#endif /* HAVE_LIBICAL */
+
+GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id)
+{
+#ifdef HAVE_LIBICAL
+	icalparser *parser = NULL;
+	icalcomponent *comp = NULL;
+	gn_error error;
+
+	parser = icalparser_new();
+	if (!parser) {
+		return GN_ERR_FAILED;
+	}
+
+	icalparser_set_gen_data(parser, f);
+
+	comp = icalparser_parse(parser, ical_fgets);
+	if (!comp) {
+		icalparser_free(parser);
+		return GN_ERR_FAILED;
+	}
+
+	error = gn_ical2todo_real(comp, ctodo, id);
+
 	icalcomponent_free(comp);
 	icalparser_free(parser);
 
-	return GN_ERR_NONE;
+	return error;
+#else
+	return GN_ERR_NOTIMPLEMENTED;
+#endif /* HAVE_LIBICAL */
+}
+
+GNOKII_API int gn_icalstr2todo(const char * ical, gn_todo *ctodo, int id)
+{
+#ifdef HAVE_LIBICAL
+	icalparser *parser = NULL;
+	icalcomponent *comp = NULL;
+	gn_error error;
+
+	parser = icalparser_new();
+	if (!parser) {
+		return GN_ERR_FAILED;
+	}
+
+	comp = icalparser_parse_string (ical);
+	if (!comp) {
+		icalparser_free(parser);
+		return GN_ERR_FAILED;
+	}
+
+	error = gn_ical2todo_real(comp, ctodo, id);
+
+	icalcomponent_free(comp);
+	icalparser_free(parser);
+
+	return error;
 #else
 	return GN_ERR_NOTIMPLEMENTED;
 #endif /* HAVE_LIBICAL */
