@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-file.c,v 1.12 2008/04/12 12:53:48 pkot Exp $
+  $Id: gnokii-file.c,v 1.15 2008/09/29 13:32:20 dforsi Exp $
 
   G N O K I I
 
@@ -238,10 +238,10 @@ gn_error deletefilebyid(char *id, gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-void getfile_usage(FILE *f, int exitval)
+int getfile_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --getfile remote_filename [localfilename]\n"));
-	exit(exitval);
+	return exitval;
 }
 
 /* Get file */
@@ -253,7 +253,7 @@ gn_error getfile(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 	char filename2[512];
 
 	if (argc < optind)
-		getfile_usage(stderr, -1);
+		return getfile_usage(stderr, -1);
 
 	memset(filename2, 0, 512);
 	memset(&fi, 0, sizeof(fi));
@@ -262,6 +262,8 @@ gn_error getfile(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 	gn_data_clear(data);
 	data->file = &fi;
 
+	data->progress_indication = NULL;
+
 	if ((error = gn_sm_functions(GN_OP_GetFile, data, state)) != GN_ERR_NONE)
 		fprintf(stderr, _("Failed to get file %s: %s\n"), optarg, gn_error_print(error));
 	else {
@@ -300,10 +302,10 @@ gn_error getfile(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 	return error;
 }
 
-void getfilebyid_usage(FILE *f, int exitval)
+int getfilebyid_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --getfilebyid id [localfilename]\n"));
-	exit(exitval);
+	return exitval;
 }
 
 /* Get file */
@@ -316,7 +318,7 @@ gn_error getfilebyid(int argc, char *argv[], gn_data *data, struct gn_statemachi
 	char filename2[512];
 
 	if (argc < optind)
-		getfilebyid_usage(stderr, -1);
+		return getfilebyid_usage(stderr, -1);
 
 	memset(filename2, 0, 512);
 	memset(&fi, 0, sizeof(fi));
@@ -326,6 +328,8 @@ gn_error getfilebyid(int argc, char *argv[], gn_data *data, struct gn_statemachi
 	data->file = &fi;
 	data->file_list = &fil;
 
+	data->progress_indication = NULL;
+
 	if ((error = gn_sm_functions(GN_OP_GetFileDetailsById, data, state)) != GN_ERR_NONE)
 		fprintf(stderr, _("Failed to get file: %s\n"), gn_error_print(error));
 	else {
@@ -408,10 +412,10 @@ gn_error getallfiles(char *path, gn_data *data, struct gn_statemachine *state)
 	return error;
 }
 
-void putfile_usage(FILE *f, int exitval)
+int putfile_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --putfile local_filename remote_filename\n"));
-	exit(exitval);
+	return exitval;
 }
 
 /* Put file */
@@ -422,7 +426,7 @@ gn_error putfile(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 	FILE *f;
 
 	if (argc != optind + 1)
-		putfile_usage(stderr, -1);
+		return putfile_usage(stderr, -1);
 
 	memset(&fi, 0, sizeof(fi));
 	snprintf(fi.name, 512, "%s", argv[optind]);
@@ -447,6 +451,7 @@ gn_error putfile(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		fprintf(stderr, _("Failed to put file to %s: %s\n"), argv[optind], gn_error_print(error));
 
 	free(fi.file);
+//fclose(f);
 
 	return error;
 }
