@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-sms.c,v 1.42 2008/05/29 14:39:36 pkot Exp $
+  $Id: gnokii-sms.c,v 1.55 2008/10/05 10:36:25 pkot Exp $
 
   G N O K I I
 
@@ -85,7 +85,7 @@ void sms_usage(FILE *f)
 }
 
 /* Displays usage of --sendsms command */
-void sendsms_usage(FILE *f, int exitval)
+int sendsms_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --sendsms destination              recipient number (msisdn)\n"
 			"        --smsc message_center_number       number (msisdn) of the message\n"
@@ -108,7 +108,7 @@ void sendsms_usage(FILE *f, int exitval)
 			"        --imelody                          send imelody message, text is read\n"
 			"                                           from stdin\n"
 			"        -a file;file;file;file\n"
-			"        --animation file;file;file;file    send animation message\n" 
+			"        --animation file;file;file;file    send animation message\n"
 			"        -o this;total;serial\n"
 			"        --concat this;total;serial         send 'this' part of all 'total' parts\n"
 			"                                           identified by 'serial'\n"
@@ -117,7 +117,7 @@ void sendsms_usage(FILE *f, int exitval)
 			"Message text is read from standard input.\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Send SMS messages. */
@@ -151,16 +151,16 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 
 	memset(&sms.remote.number, 0, sizeof(sms.remote.number));
 	snprintf(sms.remote.number, sizeof(sms.remote.number), "%s", optarg);
-	if (sms.remote.number[0] == '+') 
+	if (sms.remote.number[0] == '+')
 		sms.remote.type = GN_GSM_NUMBER_International;
-	else 
+	else
 		sms.remote.type = GN_GSM_NUMBER_Unknown;
 
 	while ((i = getopt_long(argc, argv, "l:rv:C:8ia:o:w:", options, NULL)) != -1) {
 		switch (i) {       /* -c for compression. not yet implemented. */
 		case '1': /* SMSC number */
 			snprintf(sms.smsc.number, sizeof(sms.smsc.number), "%s", optarg);
-			if (sms.smsc.number[0] == '+') 
+			if (sms.smsc.number[0] == '+')
 				sms.smsc.type = GN_GSM_NUMBER_International;
 			else
 				sms.smsc.type = GN_GSM_NUMBER_Unknown;
@@ -171,7 +171,7 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			data->message_center->id = gnokii_atoi(optarg);
 			if (errno || data->message_center->id < 1 || data->message_center->id > 5) {
 				free(data->message_center);
-				sendsms_usage(stderr, -1);
+				return sendsms_usage(stderr, -1);
 			}
 			if (gn_sm_functions(GN_OP_GetSMSCenter, data, state) == GN_ERR_NONE) {
 				snprintf(sms.smsc.number, sizeof(sms.smsc.number), "%s", data->message_center->smsc.number);
@@ -183,10 +183,10 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		case 'l': /* we send long message */
 			input_len = gnokii_atoi(optarg);
 			if (errno || input_len < 0)
-				sendsms_usage(stderr, -1);
+				return sendsms_usage(stderr, -1);
 			if (input_len > 255 * GN_SMS_MAX_LENGTH) {
 				fprintf(stderr, _("Input too long! (%d, maximum is %d)\n"), input_len, 255 * GN_SMS_MAX_LENGTH);
-				return GN_ERR_FAILED;
+				return GN_ERR_INVALIDSIZE;
 			}
 			break;
 
@@ -210,8 +210,8 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		case 'o': /* Concat header */ {
 			dprintf("Adding concat header\n");
 			sms.user_data[curpos].type = GN_SMS_DATA_Concat;
-			if (3 != sscanf(optarg, "%d;%d;%d", &sms.user_data[curpos].u.concat.curr, 
-					&sms.user_data[curpos].u.concat.total, 
+			if (3 != sscanf(optarg, "%d;%d;%d", &sms.user_data[curpos].u.concat.curr,
+					&sms.user_data[curpos].u.concat.total,
 					&sms.user_data[curpos].u.concat.serial)) {
 				fprintf(stderr, _("Incorrect --concat option\n"));
 				break;
@@ -239,14 +239,14 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 				sms.dcs.u.general.m_class = 4;
 				break;
 			default:
-				sendsms_usage(stderr, -1);
+				return sendsms_usage(stderr, -1);
 			}
 			break;
 
 		case 'v':
 			sms.validity = gnokii_atoi(optarg);
 			if (errno || sms.validity < 0)
-				sendsms_usage(stderr, -1);
+				return sendsms_usage(stderr, -1);
 			break;
 
 		case '8':
@@ -262,7 +262,7 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 				return error;
 			if (sms.user_data[0].length < 1) {
 				fprintf(stderr, _("Empty message. Quitting.\n"));
-				return GN_ERR_FAILED;
+				return GN_ERR_INVALIDSIZE;
 			}
 			curpos = -1;
 			break;
@@ -270,47 +270,46 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			gn_wap_push wp;
 			int chars_read;
 			char message_buffer[GN_SMS_MAX_LENGTH];
-			
-			
+
 			if (!optarg || strlen(optarg) > 255) {
 				fprintf(stderr, _("URL is too long (max 255 chars). Quitting.\n"));
-			        return GN_ERR_FAILED;
+			        return GN_ERR_INVALIDSIZE;
 			}
-			
+
 			sms.user_data[curpos].type = GN_SMS_DATA_WAPPush;
-			
+
 			gn_wap_push_init(&wp);
 
 			memset(message_buffer, 0, sizeof(message_buffer));
-			fprintf(stderr, _("Please enter SMS text. End your input with <cr><control-D>:"));
+			fprintf(stderr, _("Please enter SMS text. End your input with <cr><control-D>:\n"));
 			chars_read = fread(message_buffer, 1, sizeof(message_buffer), stdin);
-			
+
 			wp.url = optarg;
 			wp.text = message_buffer;
-			
+
 			if (gn_wap_push_encode(&wp) != GN_ERR_NONE) {
 			    fprintf(stderr, _("WAP Push encoding failed!\n"));
 			    return GN_ERR_FAILED;
 			}
 
 			memcpy(sms.user_data[curpos].u.text, wp.data, wp.data_len);
-			
+
 			sms.user_data[curpos].length = wp.data_len;
-			
+
 			free(wp.data);
 
 			sms.user_data[++curpos].type = GN_SMS_DATA_None;
-			
+
 			curpos = -1;
 			break;
 		}
 		default:
-			sendsms_usage(stderr, -1);
+			return sendsms_usage(stderr, -1);
 		}
 	}
 	if (argc > optind) {
 		/* There are too many arguments that don't start with '-' */
-		sendsms_usage(stderr, -1);
+		return sendsms_usage(stderr, -1);
 	}
 
 	if (!sms.smsc.number[0]) {
@@ -332,7 +331,7 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		if (error != GN_ERR_NONE) return error;
 		if (sms.user_data[curpos].length < 1) {
 			fprintf(stderr, _("Empty message. Quitting.\n"));
-			return GN_ERR_FAILED;
+			return GN_ERR_INVALIDSIZE;
 		}
 		sms.user_data[curpos].type = GN_SMS_DATA_Text;
 		if (!gn_char_def_alphabet(sms.user_data[curpos].u.text))
@@ -346,7 +345,7 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 	error = gn_sms_send(data, state);
 
 	if (error == GN_ERR_NONE)
-		fprintf(stderr, _("Send succeeded!\n"));
+		fprintf(stderr, _("Send succeeded with reference %d!\n"), sms.reference);
 	else
 		fprintf(stderr, _("SMS Send failed (%s)\n"), gn_error_print(error));
 
@@ -354,7 +353,7 @@ gn_error sendsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 }
 
 /* Displays usage of --savesms command */
-void savesms_usage(FILE *f, int exitval)
+int savesms_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --savesms\n"
 			"        --smsc message_center_number    number (msisdn) of the message\n"
@@ -373,13 +372,13 @@ void savesms_usage(FILE *f, int exitval)
 			"                                        is of type IN, OU...\n"
 			"        -d\n"
 			"        --deliver                       set message type as sms deliver\n"
-			"                                        (to be sent)\n" 
+			"                                        (to be sent)\n"
 			"        -t YYMMDDHHMISS\n"
 			"        --datetime YYMMDDHHMISS         set date and time of message delivery\n"
 			"Message text is read from standard input.\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
@@ -439,7 +438,7 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		switch (i) {
 		case '0': /* SMSC number */
 			snprintf(sms.smsc.number, sizeof(sms.smsc.number) - 1, "%s", optarg);
-			if (sms.smsc.number[0] == '+') 
+			if (sms.smsc.number[0] == '+')
 				sms.smsc.type = GN_GSM_NUMBER_International;
 			else
 				sms.smsc.type = GN_GSM_NUMBER_Unknown;
@@ -449,7 +448,7 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			data->message_center->id = gnokii_atoi(optarg);
 			if (errno || data->message_center->id < 1 || data->message_center->id > 5) {
 				free(data->message_center);
-				savesms_usage(stderr, -1);
+				return savesms_usage(stderr, -1);
 			}
 			if (gn_sm_functions(GN_OP_GetSMSCenter, data, state) == GN_ERR_NONE) {
 				snprintf(sms.smsc.number, sizeof(sms.smsc.number), "%s", data->message_center->smsc.number);
@@ -464,10 +463,10 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 				sms.remote.type = GN_GSM_NUMBER_Unknown;
 			snprintf(sms.remote.number, GN_BCD_STRING_MAX_LENGTH, "%s", optarg);
 			break;
-		case '3': /* location to write to */
+		case 'l': /* location to write to */
 			sms.number = gnokii_atoi(optarg);
 			if (errno || sms.number < 0)
-				savesms_usage(stderr, -1);
+				return savesms_usage(stderr, -1);
 			break;
 		case 's': /* mark the message as sent */
 		case 'r': /* mark the message as read */
@@ -482,7 +481,7 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			snprintf(memory_type, 19, "%s", optarg);
 			if (gn_str2memory_type(memory_type) == GN_MT_XX) {
 				fprintf(stderr, _("Unknown memory type %s (use ME, SM, ...)!\n"), optarg);
-				return -1;
+				return GN_ERR_INVALIDMEMORYTYPE;
 			}
 			break;
 		case 'd': /* type Deliver */
@@ -491,12 +490,12 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		case 't': /* set specific date and time of message delivery */
 			if (strlen(optarg) != 12) {
 				fprintf(stderr, _("Invalid datetime format: %s (should be YYMMDDHHMISS, all digits)!\n"), optarg);
-				return -1;
+				return GN_ERR_WRONGDATAFORMAT;
 			}
 			for (i = 0; i < 12; i++)
 				if (!isdigit(optarg[i])) {
 					fprintf(stderr, _("Invalid datetime format: %s (should be YYMMDDHHMISS, all digits)!\n"), optarg);
-					return -1;
+					return GN_ERR_WRONGDATAFORMAT;
 				}
 			snprintf(tmp, sizeof(tmp), "%s", optarg);
 			sms.smsc_time.year	= atoi(tmp) + 1900;
@@ -512,16 +511,16 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			sms.smsc_time.second	= atoi(tmp);
 			if (!gn_timestamp_isvalid(sms.smsc_time)) {
 				fprintf(stderr, _("Invalid datetime: %s.\n"), optarg);
-				return -1;
+				return GN_ERR_WRONGDATAFORMAT;
 			}
 			break;
 		default:
-			savesms_usage(stderr, -1);
+			return savesms_usage(stderr, -1);
 		}
 	}
 	if (argc > optind) {
 		/* There are too many arguments that don't start with '-' */
-		savesms_usage(stderr, -1);
+		return savesms_usage(stderr, -1);
 	}
 #if 0
 	if (interactive) {
@@ -569,7 +568,7 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 		return error;
 	if (sms.user_data[0].length < 1) {
 		fprintf(stderr, _("Empty message. Quitting.\n"));
-		return -1;
+		return GN_ERR_WRONGDATAFORMAT;
 	}
 	if (memory_type[0] != '\0')
 		sms.memory_type = gn_str2memory_type(memory_type);
@@ -593,7 +592,7 @@ gn_error savesms(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 }
 
 /* Displays usage of --getsms command */
-void getsms_usage(FILE *f, int exitval)
+int getsms_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --getsms memory start [end]  retrieves messages from memory type (SM, ME,\n"
 			"                                    IN, OU, ...) starting from\n"
@@ -612,12 +611,12 @@ void getsms_usage(FILE *f, int exitval)
 			"        -f filename                 as above but user is prompted before\n"
 			"                                    overwriting the file\n"
 			"        --append-file filename\n"
-			"        -a filename                 as above but append to the exising file\n"
+			"        -a filename                 as above but append to the existing file\n"
 			"        --delete\n"
 			"        -d                          delete message after reading\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Get SMS messages. */
@@ -645,20 +644,19 @@ gn_error getsms(int argc, char *argv[], gn_data *data, struct gn_statemachine *s
 		{ NULL,         0,                 NULL, 0 }
 	};
 
-
 	/* Handle command line args that set type, start and end locations. */
 	memory_type_string = optarg;
 	if (gn_str2memory_type(memory_type_string) == GN_MT_XX) {
 		fprintf(stderr, _("Unknown memory type %s (use ME, SM, IN, OU, ...)!\n"), optarg);
-		return GN_ERR_FAILED;
+		return GN_ERR_INVALIDMEMORYTYPE;
 	}
 
 	start_message = gnokii_atoi(argv[optind]);
 	if (errno || start_message < 0)
-		getsms_usage(stderr, -1);
+		return getsms_usage(stderr, -1);
 	end_message = parse_end_value_option(argc, argv, optind + 1, start_message);
 	if (errno || end_message < 0)
-		getsms_usage(stderr, -1);
+		return getsms_usage(stderr, -1);
 
 	*filename = '\0';
 	/* parse all options (beginning with '-') */
@@ -681,15 +679,15 @@ parsefile:
 				snprintf(filename, sizeof(filename), "%s", optarg);
 				fprintf(stderr, _("Saving into %s\n"), filename);
 			} else
-				getsms_usage(stderr, -1);
+				return getsms_usage(stderr, -1);
 			break;
 		default:
-			getsms_usage(stderr, -1);
+			return getsms_usage(stderr, -1);
 		}
 	}
 	if (argc - optind > 3) {
 		/* There are too many arguments that don't start with '-' */
-		getsms_usage(stderr, -1);
+		return getsms_usage(stderr, -1);
 	}
 
 	folder.folder_id = 0;
@@ -841,7 +839,7 @@ parsefile:
 					free(mbox);
 				}
 			}
-			if (del) {
+			if (del && mode != -1) {
 				data->sms = &message;
 				if (GN_ERR_NONE != gn_sms_delete(data, state))
 					fprintf(stderr, _("(delete failed)\n"));
@@ -859,7 +857,8 @@ parsefile:
 				return error;
 			break;
 		}
-	}
+		if (mode == -1)
+			break;	}
 
 	/* FIXME: We return the value of the last read.
 	 * What should we return?
@@ -868,7 +867,7 @@ parsefile:
 }
 
 /* Displays usage of --deletesms command */
-void deletesms_usage(FILE *f, int exitval)
+int deletesms_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --deletesms memory start [end]  deletes messages from memory type\n"
 			"                                       (SM, ME, IN, OU, ...) starting\n"
@@ -879,7 +878,7 @@ void deletesms_usage(FILE *f, int exitval)
 			"                                       until empty location\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Delete SMS messages. */
@@ -902,10 +901,10 @@ gn_error deletesms(int argc, char *argv[], gn_data *data, struct gn_statemachine
 
 	start_message = gnokii_atoi(argv[optind]);
 	if (errno || start_message < 0)
-		deletesms_usage(stderr, -1);
+		return deletesms_usage(stderr, -1);
 	end_message = parse_end_value_option(argc, argv, optind + 1, start_message);
 	if (errno || end_message < 0)
-		deletesms_usage(stderr, -1);
+		return deletesms_usage(stderr, -1);
 
 	/* Now delete the requested entries. */
 	for (count = start_message; count <= end_message; count++) {
@@ -931,7 +930,7 @@ gn_error deletesms(int argc, char *argv[], gn_data *data, struct gn_statemachine
 }
 
 /* Displays usage of --getsmsc command */
-void getsmsc_usage(FILE *f, int exitval)
+int getsmsc_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --getsmsc [start [end]]       reads message center details from\n"
 			"                                     the phone starting with start location\n"
@@ -945,7 +944,7 @@ void getsmsc_usage(FILE *f, int exitval)
 			"                                     default is human readable form\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Get SMSC number */
@@ -966,31 +965,31 @@ gn_error getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 			raw = true;
 			break;
 		default:
-			getsmsc_usage(stderr, -1);
+			return getsmsc_usage(stderr, -1);
 		}
 	}
 
 	if (argc > optind + 2) {
 		/* There are too many arguments that don't start with '-' */
-		getsmsc_usage(stderr, -1);
+		return getsmsc_usage(stderr, -1);
 	}
 
 	if (argc > optind) {
 		start = gnokii_atoi(argv[optind]);
 		if (errno || start < 0)
-			getsmsc_usage(stderr, -1);
+			return getsmsc_usage(stderr, -1);
 		stop = parse_end_value_option(argc, argv, optind + 1, start);
 		if (errno || stop < 0)
-			getsmsc_usage(stderr, -1);
+			return getsmsc_usage(stderr, -1);
 
 		if (start > stop) {
 			fprintf(stderr, _("Starting SMS center number is greater than stop\n"));
-			return GN_ERR_FAILED;
+			return GN_ERR_INVALIDLOCATION;
 		}
 
 		if (start < 1) {
 			fprintf(stderr, _("SMS center number must be greater than 0\n"));
-			return GN_ERR_FAILED;
+			return GN_ERR_INVALIDLOCATION;
 		}
 	} else {
 		start = 1;
@@ -1042,13 +1041,13 @@ gn_error getsmsc(int argc, char *argv[], gn_data *data, struct gn_statemachine *
 }
 
 /* Displays usage of --setsmsc command */
-void setsmsc_usage(FILE *f, int exitval)
+int setsmsc_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --setsmsc\n"
 			"SMSC details are read from standard input.\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Set SMSC number */
@@ -1099,12 +1098,12 @@ gn_error setsmsc(gn_data *data, struct gn_statemachine *state)
 }
 
 /* Displays usage of --createsmsfolder command */
-void createsmsfolder_usage(FILE *f, int exitval)
+int createsmsfolder_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --createsmsfolder name     creates SMS folder with given name\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Creating SMS folder. */
@@ -1121,18 +1120,18 @@ gn_error createsmsfolder(char *name, gn_data *data, struct gn_statemachine *stat
 	error = gn_sm_functions(GN_OP_CreateSMSFolder, data, state);
 	if (error != GN_ERR_NONE)
 		fprintf(stderr, _("Error: %s\n"), gn_error_print(error));
-	else 
+	else
 		fprintf(stderr, _("Folder with name: %s successfully created!\n"), folder.name);
 	return error;
 }
 
 /* Displays usage of --deletesmsfolder command */
-void deletesmsfolder_usage(FILE *f, int exitval)
+int deletesmsfolder_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --deletesmsfolder folderid    removes SMS folder with given id\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 /* Deleting SMS folder. */
@@ -1146,24 +1145,26 @@ gn_error deletesmsfolder(char *number, gn_data *data, struct gn_statemachine *st
 	folder.folder_id = gnokii_atoi(number);
 	if (!errno && folder.folder_id > 0 && folder.folder_id <= GN_SMS_FOLDER_MAX_NUMBER)
 		data->sms_folder = &folder;
-	else
+	else {
 		fprintf(stderr, _("Error: Number must be between 1 and %i!\n"), GN_SMS_FOLDER_MAX_NUMBER);
+		return GN_ERR_INVALIDLOCATION;
+	}
 
 	error = gn_sm_functions(GN_OP_DeleteSMSFolder, data, state);
 	if (error != GN_ERR_NONE)
 		fprintf(stderr, _("Error: %s\n"), gn_error_print(error));
-	else 
+	else
 		fprintf(stderr, _("Number %i of 'My Folders' successfully deleted!\n"), folder.folder_id);
 	return error;
 }
 
 /* Displays usage of --showsmsfolderstatus command */
-void showsmsfolderstatus_usage(FILE *f, int exitval)
+int showsmsfolderstatus_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --showsmsfolderstatus     shows summary of SMS folders\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 gn_error showsmsfolderstatus(gn_data *data, struct gn_statemachine *state)
@@ -1181,15 +1182,15 @@ gn_error showsmsfolderstatus(gn_data *data, struct gn_statemachine *state)
 		return error;
 	}
 
-	fprintf(stdout, _("No. Name                             Id #Msg\n"));
-	fprintf(stdout, _("============================================\n"));
+	fprintf(stdout, _("No. Name                               Id #Msg\n"));
+	fprintf(stdout, _("==============================================\n"));
 	for (i = 0; i < folders.number; i++) {
 		data->sms_folder = folders.folder + i;
 		if ((error = gn_sm_functions(GN_OP_GetSMSFolderStatus, data, state)) != GN_ERR_NONE) {
 			fprintf(stderr, _("Cannot stat folder \"%s\": %s\n"), folders.folder[i].name, gn_error_print(error));
 			return error;
 		}
-		fprintf(stdout, _("%3d %-32s %2s %4u\n"), i, folders.folder[i].name, gn_memory_type2str(folders.folder_id[i]), folders.folder[i].number);
+		fprintf(stdout, _("%3d %-32s %4s %4u\n"), i, folders.folder[i].name, gn_memory_type2str(folders.folder_id[i]), folders.folder[i].number);
 	}
 
 	return GN_ERR_NONE;
@@ -1256,13 +1257,13 @@ static gn_error smsslave(gn_sms *message, struct gn_statemachine *state, void *c
 }
 
 /* Displays usage of --smsreader command */
-void smsreader_usage(FILE *f, int exitval)
+int smsreader_usage(FILE *f, int exitval)
 {
 	fprintf(f, _(" usage: --smsreader     periodically check sms on the phone and stores them\n"
 			"                       in mbox format\n"
 			"\n"
 		));
-	exit(exitval);
+	return exitval;
 }
 
 gn_error smsreader(gn_data *data, struct gn_statemachine *state)
