@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii.h.in,v 1.7 2008/05/30 15:33:00 dforsi Exp $
+  $Id: gnokii.h.in,v 1.13 2008/06/23 15:08:30 hadess Exp $
 
   G N O K I I
 
@@ -64,9 +64,9 @@ typedef unsigned char uint8_t;
 #  endif
 #endif
 
-#define LIBGNOKII_VERSION_STRING "3.9.0"
-#define LIBGNOKII_VERSION_MAJOR 3
-#define LIBGNOKII_VERSION_MINOR 9
+#define LIBGNOKII_VERSION_STRING "4.0.0"
+#define LIBGNOKII_VERSION_MAJOR 4
+#define LIBGNOKII_VERSION_MINOR 0
 #define LIBGNOKII_VERSION_RELEASE 0
 #define LIBGNOKII_MAKE_VERSION( a,b,c ) (((a) << 16) | ((b) << 8) | (c))
 
@@ -267,8 +267,10 @@ GNOKII_API void gn_cfg_free_default() GNOKII_DEPRECATED;
 GNOKII_API gn_error gn_cfg_phone_load(const char *iname, struct gn_statemachine *state) GNOKII_DEPRECATED;
 
 /* In/Out routines, file formats */
-GNOKII_API int gn_phonebook2vcard(FILE *f, gn_phonebook_entry *entry, char *location);
-GNOKII_API int gn_vcard2phonebook(FILE *f, gn_phonebook_entry *entry);
+GNOKII_API int gn_phonebook2vcard(FILE *f, gn_phonebook_entry *entry, char *location) GNOKII_DEPRECATED;
+GNOKII_API char * gn_phonebook2vcardstr(gn_phonebook_entry *entry);
+GNOKII_API int gn_vcard2phonebook(FILE *f, gn_phonebook_entry *entry) GNOKII_DEPRECATED;
+GNOKII_API int gn_vcardstr2phonebook(const char *vcard, gn_phonebook_entry *entry);
 
 GNOKII_API int gn_phonebook2ldif(FILE *f, gn_phonebook_entry *entry);
 GNOKII_API int gn_ldif2phonebook(FILE *f, gn_phonebook_entry *entry);
@@ -281,11 +283,16 @@ GNOKII_API gn_error gn_file_phonebook_raw_write(FILE *f, gn_phonebook_entry *ent
 GNOKII_API int gn_vcal_file_event_read(char *filename, gn_calnote *cnote, int number) GNOKII_DEPRECATED;
 GNOKII_API int gn_vcal_file_todo_read(char *filename, gn_todo *ctodo, int number) GNOKII_DEPRECATED;
 
-GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote);
-GNOKII_API int gn_ical2calnote(FILE *f, gn_calnote *calnote, int id);
+GNOKII_API int gn_calnote2ical(FILE *f, gn_calnote *calnote) GNOKII_DEPRECATED;
+GNOKII_API char * gn_calnote2icalstr (gn_calnote *calnote);
+GNOKII_API gn_error gn_ical2calnote(FILE *f, gn_calnote *calnote, int id) GNOKII_DEPRECATED;
+GNOKII_API gn_error gn_icalstr2calnote(const char * ical, gn_calnote *calnote, int id);
 
-GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo);
-GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id);
+
+GNOKII_API int gn_todo2ical(FILE *f, gn_todo *ctodo) GNOKII_DEPRECATED;
+GNOKII_API char * gn_todo2icalstr(gn_todo *ctodo);
+GNOKII_API int gn_ical2todo(FILE *f, gn_todo *ctodo, int id) GNOKII_DEPRECATED;
+GNOKII_API int gn_icalstr2todo(const char * ical, gn_todo *ctodo, int id);
 
 GNOKII_API void gn_number_sanitize(char *number, int maxlen);
 GNOKII_API void gn_phonebook_entry_sanitize(gn_phonebook_entry *entry);
