@@ -1,10 +1,10 @@
 /*
 
-  $Id: fbus.h,v 1.19 2003/03/06 21:38:45 pkot Exp $
+  $Id: fbus.h,v 1.22 2007/12/16 16:04:04 pkot Exp $
 
   G N O K I I
 
-  A Linux/Unix toolset and driver for Nokia mobile phones.
+  A Linux/Unix toolset and driver for the mobile phones.
 
   This file is part of gnokii.
 
@@ -22,8 +22,9 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 2000 Hugh Blemings & Pavel Jank ml.
-  Copyright (C) 2000 Chris Kemp
+  Copyright (C) 1999-2000 Hugh Blemings & Pavel Janik ml.
+  Copyright (C) 2000      Chris Kemp
+  Copyright (C) 2002      BORBELY Zoltan, Pawel Kot, Ladis Michl
 
   This file provides an API for accessing functions via fbus.
   See README for more details on supported mobile phones.
@@ -40,7 +41,6 @@
 #  include <sys/types.h>
 #endif
 
-#include "config.h"
 #include "compat.h"
 
 #include "fbus-common.h"
@@ -95,6 +95,7 @@ typedef struct {
 	fbus_incoming_frame i;
 	fbus_incoming_message messages[FBUS_MESSAGE_MAX_TYPES];
 	u8 request_sequence_number;
+	u8 init_frame;
 } fbus_link;
 
 gn_error fbus_initialise(int attempt, struct gn_statemachine *state);
