@@ -1,6 +1,6 @@
 /*
 
-  $Id: nk6510.h,v 1.34 2008/05/30 19:06:25 pkot Exp $
+  $Id: nk6510.h,v 1.39 2008/10/05 10:50:02 pkot Exp $
 
   G N O K I I
 
@@ -199,16 +199,34 @@ typedef enum {
 
 #define NK6510_FILE_ID_LENGTH 6
 
+/*
+ * For Nokia Series40 3rd edition, we implement GetSMS with files commands.
+ * Algorithm is:
+ *   - get file list
+ *   - filter sms files by name
+ *   - get file
+ * It is repeated for every SMS. As 'get file list' is the longest opration
+ * it makes sense to cache the results. Define here for how long (seconds)
+ * data is cached.
+ */
+#define NK6510_FILE_CACHE_TIMEOUT	10	/* seconds */
+#define NK6510_GETFILELIST_TIMEOUT	500	/* miliseconds */
+
 typedef struct {
 	/* callbacks */
 	void (*on_cell_broadcast)(gn_cb_message *msg, struct gn_statemachine *state, void *callback_data);
 	void (*call_notification)(gn_call_status call_status, gn_call_info *call_info, struct gn_statemachine *state, void *callback_data);
 	gn_error (*on_sms)(gn_sms *message, struct gn_statemachine *state, void *callback_data);
+	void (*progress_indication)(int progress, void *callback_data);
+
+	/* phone model capabilities */
+	gn_phone_model *pm;
 
 	/* callback local data */
-	void *cb_callback_data;	/* to be passed as callback_data to on_cell_broadcast */
+	void *cb_callback_data;		/* to be passed as callback_data to on_cell_broadcast */
 	void *call_callback_data;	/* to be passed as callback_data to call_notification */
 	void *sms_callback_data;	/* to be passed as callback_data to on_sms */
+	void *progress_callback_data;	/* to be passed as callback_data to progress_indication */
 } nk6510_driver_instance;
 
 #endif  /* _gnokii_phones_nk6510_h */
