@@ -1,6 +1,6 @@
 /*
 
-  $Id: config.h,v 1.35 2008/05/30 19:34:54 pkot Exp $
+  $Id: config.h,v 1.37 2008/10/05 12:14:13 pkot Exp $
 
   G N O K I I
 
@@ -39,7 +39,7 @@
 #endif
 	
 #undef VERSION
-#define VERSION "0.6.26"
+#define VERSION "0.6.27"
 
 /* No bluetooth and no IRDA */
 #undef HAVE_BLUETOOTH
@@ -82,7 +82,7 @@
 #undef HAVE_TERMIOS_CSPEED
 
 /* Define both if you have ISO C99 compliant snprintf */
-#define HAVE_SNPRINTF
+#undef HAVE_SNPRINTF
 #undef HAVE_C99_SNPRINTF
 
 /* Define both if you have ISO C99 compliant vsnprintf */
