@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_cfg.c,v 1.19 2007/12/04 19:27:37 hadess Exp $
+  $Id: xgnokii_cfg.c,v 1.20 2008/10/05 19:06:33 pkot Exp $
 
   X G N O K I I
 
@@ -75,7 +75,7 @@ static void GetDefaultValues()
 	xgnokiiConfig.user.fax = g_strdup("");
 	xgnokiiConfig.user.email = g_strdup("");
 	xgnokiiConfig.user.address = g_strdup("");
-	xgnokiiConfig.helpviewer = g_strdup("mozilla");
+	xgnokiiConfig.helpviewer = g_strdup("firefox");
 	if ((homedir = g_get_home_dir()) == NULL)
 		homedir = "";
 	xgnokiiConfig.mailbox = g_strdup_printf("%s/Mail/smsbox", homedir);
