@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_dtmf.c,v 1.16 2006/08/15 10:57:20 dforsi Exp $
+  $Id: xgnokii_dtmf.c,v 1.18 2007/12/04 19:27:37 hadess Exp $
 
   X G N O K I I
 
@@ -22,11 +22,13 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak.
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include "misc.h"
@@ -217,14 +219,14 @@ static GtkItemFactoryEntry menu_items[] = {
 
 static void InitMainMenu(void)
 {
-	menu_items[0].path = g_strdup(_("/_File"));
-	menu_items[1].path = g_strdup(_("/File/_Open"));
-	menu_items[2].path = g_strdup(_("/File/_Save"));
-	menu_items[3].path = g_strdup(_("/File/Sep1"));
-	menu_items[4].path = g_strdup(_("/File/_Close"));
-	menu_items[5].path = g_strdup(_("/_Help"));
-	menu_items[6].path = g_strdup(_("/Help/_Help"));
-	menu_items[7].path = g_strdup(_("/Help/_About"));
+	menu_items[0].path = _("/_File");
+	menu_items[1].path = _("/File/_Open");
+	menu_items[2].path = _("/File/_Save");
+	menu_items[3].path = _("/File/Sep1");
+	menu_items[4].path = _("/File/_Close");
+	menu_items[5].path = _("/_Help");
+	menu_items[6].path = _("/Help/_Help");
+	menu_items[7].path = _("/Help/_About");
 }
 
 
