@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_logos.c,v 1.43 2006/08/16 12:22:41 dforsi Exp $
+  $Id: xgnokii_logos.c,v 1.48 2007/12/15 18:21:30 pkot Exp $
    
   X G N O K I I
 
@@ -22,7 +22,7 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999      Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999      Pavel Janik ml., Hugh Blemings
   Copyright (C) 1999-2005 Jan Derfinak
   Copyright (C) 2000-2001 Marcin Wiacek, Chris Kemp
   Copyright (C) 2002-2006 Pawel Kot
@@ -30,6 +30,8 @@
 
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -991,7 +993,7 @@ void GetLogoEvent(GtkWidget * widget)
 
 	/* prepare data for event */
 	sscanf(netcou, "%s (%[^)])", network, country);
-	strncpy(bitmap.netcode, gn_network_code_find(network, country), 7);
+	strncpy(bitmap.netcode, gn_network_code_find(network, country), sizeof(bitmap.netcode));
 	data->bitmap = &bitmap;
 	e->event = Event_GetBitmap;
 	e->data = data;
@@ -1033,7 +1035,7 @@ void SetLogoEvent(GtkWidget * widget)
 
 	/* prepare data */
 	sscanf(netcou, "%s (%[^)])", network, country);
-	strncpy(bitmap.netcode, gn_network_code_find(network, country), 7);
+	strncpy(bitmap.netcode, gn_network_code_find(network, country), sizeof(bitmap.netcode));
 
 	if (bitmap.type == GN_BMP_CallerLogo) {
 		/* above condition must be there, because if you launch logos before
@@ -1247,12 +1249,12 @@ gint ToolTypeEvent(GtkWidget * widget)
 	return 0;
 }
 
-/* this is launched when logo type was change by buttons on toolbar */
+/* this is launched when logo type was changed by buttons on toolbar */
 gint LogoTypeEvent(GtkWidget * widget)
 {
 	int clear = 0;
-	g_print("LogoTypeEvent called!\n");
-	g_print("width: %i, height: %i\n", statemachine->driver.phone.startup_logo_width,
+	gn_log_xdebug("LogoTypeEvent called!\n");
+	gn_log_xdebug("width: %i, height: %i\n", statemachine->driver.phone.startup_logo_width,
 		statemachine->driver.phone.startup_logo_height);
 	/* is startupLogo? */
 	/* Resize and clear anyway - CK */
@@ -1313,7 +1315,7 @@ void ExportLogoFileMain(gchar * name)
 
 	tbitmap = bitmap;
 
-	strncpy(tbitmap.netcode, gn_network_code_get(networkInfo.network_code), 7);
+	strncpy(tbitmap.netcode, gn_network_code_get(networkInfo.network_code), sizeof(tbitmap.netcode));
 
 	error = gn_file_bitmap_save(name, &tbitmap, &statemachine->driver.phone);
 	if (error != GN_ERR_NONE) {
@@ -1468,27 +1470,27 @@ static GtkItemFactoryEntry logosMenuItems[] = {
 
 void InitLogosMenu(void)
 {
-	logosMenuItems[0].path = g_strdup(_("/_File"));
-	logosMenuItems[1].path = g_strdup(_("/File/_Open"));
-	logosMenuItems[2].path = g_strdup(_("/File/_Save"));
-	logosMenuItems[3].path = g_strdup(_("/File/Save _as ..."));
-	logosMenuItems[4].path = g_strdup(_("/File/Sep1"));
-	logosMenuItems[5].path = g_strdup(_("/File/_Get operator"));
-	logosMenuItems[6].path = g_strdup(_("/File/Get _logo"));
-	logosMenuItems[7].path = g_strdup(_("/File/Se_t logo"));
-	logosMenuItems[8].path = g_strdup(_("/File/Sep2"));
-	logosMenuItems[9].path = g_strdup(_("/File/_Close"));
-	logosMenuItems[10].path = g_strdup(_("/_Edit"));
-	logosMenuItems[11].path = g_strdup(_("/Edit/_Clear"));
-	logosMenuItems[12].path = g_strdup(_("/Edit/_Invert"));
-	logosMenuItems[13].path = g_strdup(_("/Edit/Sep3"));
-	logosMenuItems[14].path = g_strdup(_("/Edit/_Up logo"));
-	logosMenuItems[15].path = g_strdup(_("/Edit/_Down logo"));
-	logosMenuItems[16].path = g_strdup(_("/Edit/_Left logo"));
-	logosMenuItems[17].path = g_strdup(_("/Edit/_Right logo"));
-	logosMenuItems[18].path = g_strdup(_("/Edit/Sep4"));
-	logosMenuItems[19].path = g_strdup(_("/Edit/Flip _horizontal"));
-	logosMenuItems[20].path = g_strdup(_("/Edit/Flip _vertical"));
+	logosMenuItems[0].path = _("/_File");
+	logosMenuItems[1].path = _("/File/_Open");
+	logosMenuItems[2].path = _("/File/_Save");
+	logosMenuItems[3].path = _("/File/Save _as ...");
+	logosMenuItems[4].path = _("/File/Sep1");
+	logosMenuItems[5].path = _("/File/_Get operator");
+	logosMenuItems[6].path = _("/File/Get _logo");
+	logosMenuItems[7].path = _("/File/Se_t logo");
+	logosMenuItems[8].path = _("/File/Sep2");
+	logosMenuItems[9].path = _("/File/_Close");
+	logosMenuItems[10].path = _("/_Edit");
+	logosMenuItems[11].path = _("/Edit/_Clear");
+	logosMenuItems[12].path = _("/Edit/_Invert");
+	logosMenuItems[13].path = _("/Edit/Sep3");
+	logosMenuItems[14].path = _("/Edit/_Up logo");
+	logosMenuItems[15].path = _("/Edit/_Down logo");
+	logosMenuItems[16].path = _("/Edit/_Left logo");
+	logosMenuItems[17].path = _("/Edit/_Right logo");
+	logosMenuItems[18].path = _("/Edit/Sep4");
+	logosMenuItems[19].path = _("/Edit/Flip _horizontal");
+	logosMenuItems[20].path = _("/Edit/Flip _vertical");
 }
 
 void GUI_CreateLogosWindow(void)
@@ -1621,6 +1623,7 @@ void GUI_CreateLogosWindow(void)
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(networkCombo)->entry), FALSE);
 	gtk_toolbar_append_widget(GTK_TOOLBAR(toolBar), networkCombo, "", "");
 	gtk_widget_show(networkCombo);
+	g_list_foreach(glistNetwork, (GFunc) g_free, NULL);
 	g_list_free(glistNetwork);
 
 	callerCombo = gtk_combo_new();
@@ -1825,7 +1828,7 @@ void GUI_ShowLogosWindow(void)
 
 	/* Call to reset Startup logo size */
 	LogoTypeEvent(GUI_LogosWindow);
-	g_print("width: %i, height: %i\n", bitmap.width, bitmap.height);
+	gn_log_xdebug("width: %i, height: %i\n", bitmap.width, bitmap.height);
 	gtk_window_present(GTK_WINDOW(GUI_LogosWindow));
 
 	if (!previewAvailable && showPreviewErrorDialog) {
