@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_netmon.c,v 1.15 2006/01/15 15:13:27 dforsi Exp $
+  $Id: xgnokii_netmon.c,v 1.19 2007/12/04 19:27:37 hadess Exp $
 
   X G N O K I I
 
@@ -22,12 +22,14 @@
   along with gnokii; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  Copyright (C) 1999 Pavel Jank ml., Hugh Blemings
+  Copyright (C) 1999 Pavel Janik ml., Hugh Blemings
   & 1999-2005 Jan Derfinak.
   Copyright (C) 2002-2004 Pawel Kot
 
 */
 
+#include "config.h"
+
 #ifndef WIN32
 #  include <unistd.h>
 #endif
@@ -43,7 +45,7 @@
 #include "xpm/Display.xpm"
 
 static GtkWidget *GUI_NetmonWindow;
-static DisplayData displayData = { NULL, 0 };
+static DisplayData displayData = { NULL, NULL, 0 };
 static GtkWidget *tableLabels[4][7];
 static GtkWidget *tableProgress[7];
 
@@ -245,7 +247,7 @@ inline void GUI_ShowNetmon()
 	e->event = Event_NetMonitor;
 	e->data = (gpointer) displayData.curDisp;;
 	GUI_InsertEvent(e);
-	gtk_widget_show(GUI_NetmonWindow);
+	gtk_window_present(GTK_WINDOW(GUI_NetmonWindow));
 }
 
 static GtkItemFactoryEntry menu_items[] = {
@@ -262,42 +264,20 @@ static GtkItemFactoryEntry menu_items[] = {
 
 static void InitMainMenu(void)
 {
-	menu_items[0].path = g_strdup(_("/_File"));
-	menu_items[1].path = g_strdup(_("/File/_Close"));
-	menu_items[2].path = g_strdup(_("/_Tools"));
-	menu_items[3].path = g_strdup(_("/Tools/Net monitor o_n"));
-	menu_items[4].path = g_strdup(_("/Tools/Net monitor o_ff"));
-	menu_items[5].path = g_strdup(_("/_Help"));
-	menu_items[6].path = g_strdup(_("/Help/_Help"));
-	menu_items[7].path = g_strdup(_("/Help/_About"));
+	menu_items[0].path = _("/_File");
+	menu_items[1].path = _("/File/_Close");
+	menu_items[2].path = _("/_Tools");
+	menu_items[3].path = _("/Tools/Net monitor o_n");
+	menu_items[4].path = _("/Tools/Net monitor o_ff");
+	menu_items[5].path = _("/_Help");
+	menu_items[6].path = _("/Help/_Help");
+	menu_items[7].path = _("/Help/_About");
 }
 
 
 #define DISPLAY_X	12
 #define DISPLAY_Y	15
 
-static inline gint ExposeDisplay(GtkWidget * widget, GdkEventExpose * event)
-{
-	GdkRectangle rec;
-	GtkRequisition r;
-
-	gtk_widget_size_request(displayData.number, &r);
-	rec.x = DISPLAY_X;
-	rec.y = DISPLAY_Y;
-	rec.width = r.width;
-	rec.height = r.height;
-	gtk_widget_draw(displayData.number, &rec);
-
-	gtk_widget_size_request(displayData.label, &r);
-	rec.x += 3;
-	rec.y += 12;
-	rec.width = r.width;
-	rec.height = r.height;
-	gtk_widget_draw(displayData.label, &rec);
-
-	return FALSE;
-}
-
 
 void GUI_CreateNetmonWindow()
 {
@@ -363,9 +343,6 @@ void GUI_CreateNetmonWindow()
 	pixmap = NewPixmap(Display_xpm, GUI_NetmonWindow->window,
 			   &GUI_NetmonWindow->style->bg[GTK_STATE_NORMAL]);
 
-	gtk_signal_connect_after(GTK_OBJECT(pixmap), "expose_event",
-				 (GtkSignalFunc) ExposeDisplay, NULL);
-
 	gtk_fixed_put(GTK_FIXED(display), pixmap, 0, 0);
 	gtk_widget_show(pixmap);
 
